
using Podform3d.VirtualRhino.Core.Errors;

namespace Podform3d.VirtualRhino.Presentation.Rest.Extensions;

internal static class ResultExtensions
{
  public static async Task<ActionResult<T>> OkOrError<T>(
    this ValueTask<Result<T, Error>> result) =>
    await result.Finally<T, ActionResult<T>, Error>(result =>
    {
      if (result.IsSuccess)
      {
        return new OkObjectResult(result.Value);
      }

      return GetError<T>(result.Error);
    });

  private static ActionResult<T> GetError<T>(Error error) =>
  error switch
  {
    Error => new BadRequestObjectResult(error.Reason),
    _ => new BadRequestResult(),
  };

}
